@@ -1,4 +1,5 @@
 import asyncio
+import functools
 import os
 import re
 
@@ -6,18 +7,19 @@ import httpx
 import json
 
 from bs4 import BeautifulSoup
+
 from nonebot import on_regex, get_driver
-from nonebot.adapters.onebot.v11 import Message, Event
+from nonebot.adapters.onebot.v11 import Message, Event, Bot, MessageSegment
+from nonebot.adapters.onebot.v11.event import GroupMessageEvent
 
 from .common_utils import *
 from .bili23_utils import getDownloadUrl, downloadBFile, mergeFileToMp4, get_dynamic
-from .tiktok_utills import get_id_video
+from .tiktok_utills import get_id_video, generate_ttwid, getXbogus
 from .acfun_utils import parse_url, download_m3u8_videos, parse_m3u8, merge_ac_file_to_mp4
 from .twitter_utils import TweepyWithProxy
 
-
 # 全局配置
-global_config = get_driver().config.dict()
+global_config = get_driver().config
 resolver_proxy = getattr(global_config, "resolver_proxy", "http://127.0.0.1:7890")
 
 # twitter 代理地址
@@ -34,10 +36,12 @@ httpx_proxies = {
 client = TweepyWithProxy(
     proxies,
     getattr(global_config, "bearer_token", ""))
-
 bili23 = on_regex(
     r"(.*)(bilibili.com|b23.tv)", priority=1
 )
+
+GLOBAL_NICKNAME = "resolver"
+
 @bili23.handle()
 async def bilibili(event: Event) -> None:
     """
@@ -109,6 +113,7 @@ async def bilibili(event: Event) -> None:
     os.unlink(f"{path}-res.mp4")
     os.unlink(f"{path}-res.mp4.jpg")
 
+
 """以下为抖音/TikTok类型代码/Type code for Douyin/TikTok"""
 url_type_code_dict = {
     # 抖音/Douyin
@@ -127,15 +132,15 @@ url_type_code_dict = {
 douyin = on_regex(
     r"(.*)(v.douyin.com)", priority=1
 )
+
+
 @douyin.handle()
-async def dy(event: Event) -> None:
+async def dy(bot: Bot, event: Event) -> None:
     """
         抖音解析
     :param event:
     :return:
     """
-    header = {
-        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.4951.64 Safari/537.36'}
     # 消息
     msg: str = str(event.message).strip()
     # 正则匹配
@@ -145,12 +150,26 @@ async def dy(event: Event) -> None:
     reg2 = r".*video\/(\d+)\/(.*?)"
     # 获取到ID
     dou_id = re.search(reg2, dou_url_2, re.I)[1]
-    # 请求抖音API
-    url = f'https://www.iesdouyin.com/aweme/v1/web/aweme/detail/?aweme_id={dou_id}&aid=1128&version_name=23.5.0&device_platform=android&os_version=2333'
-    # print(url)
-    resp = httpx.get(url, headers=header).text
-    # print(resp)
-    detail = json.loads(resp)['aweme_detail']
+    # print(dou_id)
+    # 一些后续要用到的参数
+    odin_tt = 'a09d8eb0d95b7b9adb4b6fc6591918bfb996096967a7aa4305bd81b5150a8199d2e29ed21883cdd7709c5beaa2be3baa'
+    headers = {
+        'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.0.0 Safari/537.36',
+        'referer': 'https://www.douyin.com/',
+        'Cookie': f'ttwid=ttwid={generate_ttwid()};{odin_tt}'
+    }
+    # API
+    DY_API = 'https://www.douyin.com/aweme/v1/web/aweme/detail/?'
+    # 参数
+    params = f'aweme_id={dou_id}&aid=1128&version_name=23.5.0&device_platform=android&os_version=2333'
+    # 请求API
+    detail = httpx.get(f'{DY_API}{getXbogus(params)[0]}', headers=headers).json()
+    # 如果请求失败直接返回
+    if detail is None:
+        await douyin.send(Message(f"R助手极速版识别：抖音，解析失败！"))
+        return
+    # 获取信息
+    detail = detail['aweme_detail']
     # 判断是图片还是视频
     url_type_code = detail['aweme_type']
     url_type = url_type_code_dict.get(url_type_code, 'video')
@@ -161,9 +180,10 @@ async def dy(event: Event) -> None:
         player_addr = detail.get("video").get("play_addr").get("url_list")[0]
         # 发送视频
         # id = str(event.get_user_id())
-        cqs = f"[CQ:video,file={player_addr}]"
+        # cqs = f"[CQ:video,file={player_addr}]"
         # await douyin.send(MessageSegment.at(id)+Message(cqs))
-        await douyin.send(Message(cqs))
+        print(player_addr)
+        await douyin.send(Message(MessageSegment.video(player_addr)))
     elif url_type == 'image':
         # 无水印图片列表/No watermark image list
         no_watermark_image_list = []
@@ -172,15 +192,27 @@ async def dy(event: Event) -> None:
         # 遍历图片列表/Traverse image list
         for i in detail['images']:
             # 无水印图片列表
-            no_watermark_image_list.append(i['url_list'][0])
+            # no_watermark_image_list.append(i['url_list'][0])
+            no_watermark_image_list.append(
+                MessageSegment.node_custom(user_id=int(bot.self_id), nickname=GLOBAL_NICKNAME,
+                                           content=Message(f"[CQ:image,file={i['url_list'][0]}]"))
+            )
             # 有水印图片列表
             # watermark_image_list.append(i['download_url_list'][0])
         # 异步发送
-        await asyncio.gather(*[douyin.send(Message(f"[CQ:image,file={path}]")) for path in no_watermark_image_list])
+        # print(no_watermark_image_list)
+        # imgList = await asyncio.gather([])
+        if isinstance(event, GroupMessageEvent):
+            await bot.send_group_forward_msg(group_id=event.group_id, messages=no_watermark_image_list)
+        else:
+            await bot.send_private_forward_msg(user_id=event.user_id, messages=no_watermark_image_list)
+
 
 tik = on_regex(
     r"(.*)(www.tiktok.com)|(vt.tiktok.com)|(vm.tiktok.com)", priority=1
 )
+
+
 @tik.handle()
 async def tiktok(event: Event) -> None:
     """
@@ -201,7 +233,8 @@ async def tiktok(event: Event) -> None:
         url = temp_resp.url
     elif "vm.tiktok" in url:
         temp_url = re.search(url_short_reg2, url)[0]
-        temp_resp = httpx.get(temp_url, headers={"User-Agent": "facebookexternalhit/1.1"}, follow_redirects=True, proxies=httpx_proxies)
+        temp_resp = httpx.get(temp_url, headers={"User-Agent": "facebookexternalhit/1.1"}, follow_redirects=True,
+                              proxies=httpx_proxies)
         url = str(temp_resp.url)
         # print(url)
     else:
@@ -209,7 +242,7 @@ async def tiktok(event: Event) -> None:
     # strip是防止vm开头的tiktok解析出问题
     id_video = get_id_video(url).strip("/")
     print(id_video)
-    API_URL = f'https://api16-normal-c-useast1a.tiktokv.com/aweme/v1/feed/?aweme_id={ id_video }&version_code=262&app_name=musical_ly&channel=App&device_id=null&os_version=14.4.2&device_platform=iphone&device_type=iPhone13'
+    API_URL = f'https://api16-normal-c-useast1a.tiktokv.com/aweme/v1/feed/?aweme_id={id_video}&version_code=262&app_name=musical_ly&channel=App&device_id=null&os_version=14.4.2&device_platform=iphone&device_type=iPhone13'
 
     api_resp = httpx.get(API_URL, headers={
         "User-Agent": "Mozilla/5.0 (Linux; Android 5.0; SM-G900P Build/LRX21T) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.25 Mobile Safari/537.36",
@@ -218,9 +251,14 @@ async def tiktok(event: Event) -> None:
     await tik.send(Message(f"R助手极速版识别：tiktok, {data['desc']}"))
     path = await download_video_random(data['video']['play_addr']['url_list'][0])
     await tik.send(Message(f"[CQ:video,file=file:///{path}]"))
+    # 清除文件
     os.unlink(f"{path}")
+    os.unlink(f"{path}.jpg")
+
 
 acfun = on_regex(r"(.*)(acfun.cn)")
+
+
 @acfun.handle()
 async def ac(event: Event) -> None:
     """
@@ -243,14 +281,16 @@ async def ac(event: Event) -> None:
     merge_ac_file_to_mp4(ts_names, output_file_name)
     await acfun.send(Message(f"[CQ:video,file=file:///{os.getcwd()}/{output_file_name}]"))
     os.unlink(output_file_name)
-    os.unlink(output_file_name+".jpg")
+    os.unlink(output_file_name + ".jpg")
 
 
 twit = on_regex(
     r"(.*)(twitter.com)", priority=1
 )
+
+
 @twit.handle()
-async def twitter(event: Event):
+async def twitter(bot:Bot, event: Event):
     """
         推特解析
     :param event:
@@ -267,7 +307,7 @@ async def twitter(event: Event):
                                  'entities.mentions.username',
                                  'attachments.media_keys',
                              ])
-    await twit.send(Message(f"R助手极速版识别：忒特学习版，{tweet.data.text}"))
+    await twit.send(Message(f"R助手极速版识别：小蓝鸟学习版，{tweet.data.text}"))
     # print(tweet)
     # 主要内容
     tweet_json = tweet.includes
@@ -288,61 +328,83 @@ async def twitter(event: Event):
             # print(path)
             # await twit.send(Message(f"[CQ:video,file=file:///{path}]"))
             # os.unlink(f"{path}")
-    aio_task_res: tuple[str] = await asyncio.gather(*aio_task)
+    path_res = await asyncio.gather(*aio_task)
+    aio_task_res = [how_to_send_msg(int(bot.self_id), path) for path in path_res]
+
     # 发送异步后的数据
-    await asyncio.gather(*[how_to_send_msg(task) for task in aio_task_res])
+    if isinstance(event, GroupMessageEvent):
+        await bot.send_group_forward_msg(group_id=event.group_id, messages=aio_task_res)
+    else:
+        await bot.send_private_forward_msg(user_id=event.user_id, messages=aio_task_res)
+
+    # 清除垃圾
+    for path in path_res:
+        os.unlink(path)
+
 
 xhs = on_regex(
     r"(.*)(xhslink.com|xiaohongshu.com)", priority=1
 )
+
+
 @xhs.handle()
-async def redbook(event: Event):
+async def redbook(bot:Bot, event: Event):
     """
         小红书解析
     :param event:
     :return:
     """
-    msgUrl = re.search(r"(http:|https:)\/\/(xhslink|xiaohongshu).com\/[A-Za-z\d._?%&+\-=\/#@]*", str(event.message).strip())
+    msgUrl = re.search(r"(http:|https:)\/\/(xhslink|xiaohongshu).com\/[A-Za-z\d._?%&+\-=\/#@]*",
+                       str(event.message).strip())
     url = f"https://dlpanda.com/zh-CN/xhs?url={msgUrl}"
 
     resp = httpx.get(url, headers={
-                "User-Agent":
-                    "Mozilla/5.0 (Linux; Android 5.0; SM-G900P Build/LRX21T) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.25 Mobile Safari/537.36",
-                "Content-Type": "application/json",
-                "Accept-Encoding": "gzip,deflate,compress"
+        "User-Agent":
+            "Mozilla/5.0 (Linux; Android 5.0; SM-G900P Build/LRX21T) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.25 Mobile Safari/537.36",
+        "Content-Type": "application/json",
+        "Accept-Encoding": "gzip,deflate,compress"
     })
     soup = BeautifulSoup(resp.text, 'lxml')
-    urls = soup.findAll("img", attrs={"style":"max-width: none; max-height: none;"})
+    urls = soup.findAll("img", attrs={"style": "max-width: none; max-height: none;"})
     title = soup.findAll("h5")
     desc = soup.findAll("p")
     # print(title)
     # print(desc[2])
     # urls: list[str] = re.findall(r'<img(.*)src="\/\/ci\.xiaohongshu\.com(.*?)"', resp.text)
     # title_desc = re.findall(r'<a href="https:\/\/www\.xiaohongshu\.com\/discovery\/item\/(.*)<\/p>', resp.text)
-    await xhs.send(Message(f"R助手极速版识别：小红书，{''.join([str(tit.string) for tit in title[:2]])}" + "\n" + f"{str(desc[2].string)}"))
+    await xhs.send(Message(
+        f"R助手极速版识别：小红书，{''.join([str(tit.string) for tit in title[:2]])}" + "\n" + f"{str(desc[2].string)}"))
 
     aio_task = []
     for u in urls:
         # print(u.get("src"))
         link = f'https:{u.get("src")}'
         aio_task.append(download_img(link, os.getcwd() + "/" + re.search(r"com\/(.*)\?", link)[1] + ".jpg"))
-    links: tuple[str] = await asyncio.gather(*aio_task)
+    links_path: tuple[str] = await asyncio.gather(*aio_task)
     # 发送图片
-    await asyncio.gather(*[xhs.send(Message(f"[CQ:image,file=file:///{link}]")) for link in links])
+    links = [MessageSegment.node_custom(user_id=int(bot.self_id), nickname=GLOBAL_NICKNAME,
+                                           content=Message(MessageSegment.image(f"file:///{link}"))) for link in links_path]
+    # 发送异步后的数据
+    if isinstance(event, GroupMessageEvent):
+        await bot.send_group_forward_msg(group_id=event.group_id, messages=links)
+    else:
+        await bot.send_private_forward_msg(user_id=event.user_id, messages=links)
     # 清除图片
-    for temp in links:
+    for temp in links_path:
         os.unlink(temp)
 
 
-async def how_to_send_msg(task: str):
+def how_to_send_msg(user_id:int, task: str):
     """
         判断是视频还是图片然后发送最后删除
+    :param user_id:
     :param task:
     :return:
     """
-    if task.endswith("jpg" or "png"):
-        await twit.send(Message(f"[CQ:image,file=file:///{task}]"))
+    if task.endswith("jpg") or task.endswith("png"):
+        print(f"file:///{task}]")
+        return MessageSegment.node_custom(user_id=user_id, nickname=GLOBAL_NICKNAME,
+                                   content=Message(MessageSegment.image(f"file:///{task}")))
     elif task.endswith("mp4"):
-        await twit.send(Message(f"[CQ:video,file=file:///{task}]"))
-    # print(f"{os.getcwd()}/{task}")
-    os.unlink(f"{task}")
\ No newline at end of file
+        return MessageSegment.node_custom(user_id=user_id, nickname=GLOBAL_NICKNAME,
+                                          content=Message(MessageSegment.video(f"file:///{task}")))
\ No newline at end of file
